@@ -1,19 +1,22 @@
-// Copyright 2019 PDFium Authors. All rights reserved.
+// Copyright 2019 The PDFium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #include "core/fxcodec/basic/basicmodule.h"
 
+#include <stdint.h>
+
 #include <algorithm>
 #include <utility>
-#include <vector>
 
 #include "core/fxcodec/scanlinedecoder.h"
+#include "core/fxcrt/data_vector.h"
 #include "core/fxcrt/fx_memory_wrappers.h"
 #include "core/fxcrt/fx_safe_types.h"
 #include "core/fxcrt/fx_system.h"
 #include "core/fxcrt/span_util.h"
 #include "third_party/base/check.h"
+#include "third_party/base/numerics/safe_conversions.h"
 
 namespace fxcodec {
 
@@ -33,14 +36,14 @@ class RLScanlineDecoder final : public ScanlineDecoder {
   // ScanlineDecoder:
   bool Rewind() override;
   pdfium::span<uint8_t> GetNextLine() override;
-  uint32_t GetSrcOffset() override { return m_SrcOffset; }
+  uint32_t GetSrcOffset() override;
 
  private:
   bool CheckDestSize();
   void GetNextOperator();
   void UpdateOperator(uint8_t used_bytes);
 
-  std::vector<uint8_t, FxAllocAllocator<uint8_t>> m_Scanline;
+  DataVector<uint8_t> m_Scanline;
   pdfium::span<const uint8_t> m_SrcBuf;
   size_t m_dwLineBytes = 0;
   size_t m_SrcOffset = 0;
@@ -134,11 +137,13 @@ pdfium::span<uint8_t> RLScanlineDecoder::GetNextLine() {
     if (m_Operator < 128) {
       uint32_t copy_len = m_Operator + 1;
       if (col_pos + copy_len >= m_dwLineBytes) {
-        copy_len = m_dwLineBytes - col_pos;
+        copy_len =
+            pdfium::base::checked_cast<uint32_t>(m_dwLineBytes - col_pos);
         eol = true;
       }
       if (copy_len >= m_SrcBuf.size() - m_SrcOffset) {
-        copy_len = m_SrcBuf.size() - m_SrcOffset;
+        copy_len =
+            pdfium::base::checked_cast<uint32_t>(m_SrcBuf.size() - m_SrcOffset);
         m_bEOD = true;
       }
       auto copy_span = m_SrcBuf.subspan(m_SrcOffset, copy_len);
@@ -152,7 +157,8 @@ pdfium::span<uint8_t> RLScanlineDecoder::GetNextLine() {
       }
       uint32_t duplicate_len = 257 - m_Operator;
       if (col_pos + duplicate_len >= m_dwLineBytes) {
-        duplicate_len = m_dwLineBytes - col_pos;
+        duplicate_len =
+            pdfium::base::checked_cast<uint32_t>(m_dwLineBytes - col_pos);
         eol = true;
       }
       fxcrt::spanset(scan_span.subspan(col_pos, duplicate_len), fill);
@@ -166,6 +172,10 @@ pdfium::span<uint8_t> RLScanlineDecoder::GetNextLine() {
   return m_Scanline;
 }
 
+uint32_t RLScanlineDecoder::GetSrcOffset() {
+  return pdfium::base::checked_cast<uint32_t>(m_SrcOffset);
+}
+
 void RLScanlineDecoder::GetNextOperator() {
   if (m_SrcOffset >= m_SrcBuf.size()) {
     m_Operator = 128;
@@ -220,24 +230,14 @@ std::unique_ptr<ScanlineDecoder> BasicModule::CreateRunLengthDecoder(
 }
 
 // static
-bool BasicModule::RunLengthEncode(
-    pdfium::span<const uint8_t> src_span,
-    std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-    uint32_t* dest_size) {
-  // Check inputs
-  if (src_span.empty() || !dest_buf || !dest_size)
-    return false;
+DataVector<uint8_t> BasicModule::RunLengthEncode(
+    pdfium::span<const uint8_t> src_span) {
+  if (src_span.empty())
+    return {};
 
-  // Edge case
-  if (src_span.size() == 1) {
-    *dest_size = 3;
-    dest_buf->reset(FX_Alloc(uint8_t, *dest_size));
-    auto dest_buf_span = pdfium::make_span(dest_buf->get(), *dest_size);
-    dest_buf_span[0] = 0;
-    dest_buf_span[1] = src_span[0];
-    dest_buf_span[2] = 128;
-    return true;
-  }
+  // Handle edge case.
+  if (src_span.size() == 1)
+    return {0, src_span[0], 128};
 
   // Worst case: 1 nonmatch, 2 match, 1 nonmatch, 2 match, etc. This becomes
   // 4 output chars for every 3 input, plus up to 4 more for the 1-2 chars
@@ -247,10 +247,10 @@ bool BasicModule::RunLengthEncode(
   estimated_size /= 3;
   estimated_size *= 4;
   estimated_size += 1;
-  dest_buf->reset(FX_Alloc(uint8_t, estimated_size.ValueOrDie()));
+  DataVector<uint8_t> result(estimated_size.ValueOrDie());
 
-  // Set up pointers.
-  uint8_t* out = dest_buf->get();
+  // Set up span and counts.
+  auto result_span = pdfium::make_span(result);
   uint32_t run_start = 0;
   uint32_t run_end = 1;
   uint8_t x = src_span[run_start];
@@ -267,56 +267,52 @@ bool BasicModule::RunLengthEncode(
         y = src_span[run_end];
     }
     if (run_end - run_start > 1) {  // Matched run but not at end of input.
-      out[0] = 257 - (run_end - run_start);
-      out[1] = x;
+      result_span[0] = 257 - (run_end - run_start);
+      result_span[1] = x;
       x = y;
       run_start = run_end;
       run_end++;
       if (run_end < src_span.size())
         y = src_span[run_end];
-      out += 2;
+      result_span = result_span.subspan(2);
       continue;
     }
     // Mismatched run
     while (x != y && run_end <= run_start + max_len) {
-      out[run_end - run_start] = x;
+      result_span[run_end - run_start] = x;
       x = y;
       run_end++;
       if (run_end == src_span.size()) {
         if (run_end <= run_start + max_len) {
-          out[run_end - run_start] = x;
+          result_span[run_end - run_start] = x;
           run_end++;
         }
         break;
       }
       y = src_span[run_end];
     }
-    out[0] = run_end - run_start - 2;
-    out += run_end - run_start;
+    result_span[0] = run_end - run_start - 2;
+    result_span = result_span.subspan(run_end - run_start);
     run_start = run_end - 1;
   }
   if (run_start < src_span.size()) {  // 1 leftover character
-    out[0] = 0;
-    out[1] = x;
-    out += 2;
+    result_span[0] = 0;
+    result_span[1] = x;
+    result_span = result_span.subspan(2);
   }
-  *out = 128;
-  *dest_size = out + 1 - dest_buf->get();
-  return true;
+  result_span[0] = 128;
+  size_t new_size = 1 + result.size() - result_span.size();
+  CHECK_LE(new_size, result.size());
+  result.resize(new_size);
+  return result;
 }
 
 // static
-bool BasicModule::A85Encode(pdfium::span<const uint8_t> src_span,
-                            std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-                            uint32_t* dest_size) {
-  // Check inputs.
-  if (!dest_buf || !dest_size)
-    return false;
-
-  if (src_span.empty()) {
-    *dest_size = 0;
-    return false;
-  }
+DataVector<uint8_t> BasicModule::A85Encode(
+    pdfium::span<const uint8_t> src_span) {
+  DataVector<uint8_t> result;
+  if (src_span.empty())
+    return result;
 
   // Worst case: 5 output for each 4 input (plus up to 4 from leftover), plus
   // 2 character new lines each 75 output chars plus 2 termination chars. May
@@ -327,10 +323,10 @@ bool BasicModule::A85Encode(pdfium::span<const uint8_t> src_span,
   estimated_size += 4;
   estimated_size += src_span.size() / 30;
   estimated_size += 2;
-  dest_buf->reset(FX_Alloc(uint8_t, estimated_size.ValueOrDie()));
+  result.resize(estimated_size.ValueOrDie());
 
-  // Set up pointers.
-  uint8_t* out = dest_buf->get();
+  // Set up span and counts.
+  auto result_span = pdfium::make_span(result);
   uint32_t pos = 0;
   uint32_t line_length = 0;
   while (src_span.size() >= 4 && pos < src_span.size() - 3) {
@@ -338,20 +334,21 @@ bool BasicModule::A85Encode(pdfium::span<const uint8_t> src_span,
     uint32_t val = FXSYS_UINT32_GET_MSBFIRST(val_span);
     pos += 4;
     if (val == 0) {  // All zero special case
-      *out = 'z';
-      out++;
+      result_span[0] = 'z';
+      result_span = result_span.subspan(1);
       line_length++;
     } else {  // Compute base 85 characters and add 33.
       for (int i = 4; i >= 0; i--) {
-        out[i] = (uint8_t)(val % 85) + 33;
-        val = val / 85;
+        result_span[i] = (val % 85) + 33;
+        val /= 85;
       }
-      out += 5;
+      result_span = result_span.subspan(5);
       line_length += 5;
     }
     if (line_length >= 75) {  // Add a return.
-      *out++ = '\r';
-      *out++ = '\n';
+      result_span[0] = '\r';
+      result_span[1] = '\n';
+      result_span = result_span.subspan(2);
       line_length = 0;
     }
   }
@@ -365,18 +362,19 @@ bool BasicModule::A85Encode(pdfium::span<const uint8_t> src_span,
     }
     for (int i = 4; i >= 0; i--) {
       if (i <= count)
-        out[i] = (uint8_t)(val % 85) + 33;
-      val = val / 85;
+        result_span[i] = (val % 85) + 33;
+      val /= 85;
     }
-    out += count + 1;
+    result_span = result_span.subspan(count + 1);
   }
 
   // Terminating characters.
-  out[0] = '~';
-  out[1] = '>';
-  out += 2;
-  *dest_size = out - dest_buf->get();
-  return true;
+  result_span[0] = '~';
+  result_span[1] = '>';
+  size_t new_size = 2 + result.size() - result_span.size();
+  CHECK_LE(new_size, result.size());
+  result.resize(new_size);
+  return result;
 }
 
 }  // namespace fxcodec
