@@ -7,11 +7,14 @@
 #ifndef CORE_FXGE_CFX_DEFAULTRENDERDEVICE_H_
 #define CORE_FXGE_CFX_DEFAULTRENDERDEVICE_H_
 
+#include <memory>
+
 #include "core/fxcrt/retain_ptr.h"
 #include "core/fxge/cfx_renderdevice.h"
 #include "core/fxge/dib/fx_dib.h"
 
 class SkPictureRecorder;
+struct SkRect;
 
 class CFX_DefaultRenderDevice final : public CFX_RenderDevice {
  public:
@@ -33,8 +36,7 @@ class CFX_DefaultRenderDevice final : public CFX_RenderDevice {
 #if defined(_SKIA_SUPPORT_)
   bool AttachRecorder(SkPictureRecorder* recorder);
   void Clear(uint32_t color);
-  SkPictureRecorder* CreateRecorder(int size_x, int size_y);
-  void DebugVerifyBitmapIsPreMultiplied() const override;
+  std::unique_ptr<SkPictureRecorder> CreateRecorder(const SkRect& bounds);
   bool SetBitsWithMask(const RetainPtr<CFX_DIBBase>& pBitmap,
                        const RetainPtr<CFX_DIBBase>& pMask,
                        int left,
@@ -46,13 +48,6 @@ class CFX_DefaultRenderDevice final : public CFX_RenderDevice {
   // Runtime check to see if Skia is the renderer variant in use.
   static bool SkiaIsDefaultRenderer();
 
-  // Runtime check to see if SkiaPaths is the renderer variant in use.
-  static bool SkiaPathsIsDefaultRenderer();
-
-  // Convenient way to check if either SkiaIsDefaultRenderer() or
-  // SkiaPathsIsDefaultRenderer() returns true.
-  static bool SkiaVariantIsDefaultRenderer();
-
 #if defined(_SKIA_SUPPORT_)
   // This internal definition of renderer types must stay updated with respect
   // to the public definition of `FPDF_RENDERER_TYPE`, so that all public
@@ -83,7 +78,7 @@ class CFX_DefaultRenderDevice final : public CFX_RenderDevice {
                  FXDIB_Format format,
                  RetainPtr<CFX_DIBitmap> pBackdropBitmap);
 
-#if defined(_SKIA_SUPPORT_) || defined(_SKIA_SUPPORT_PATHS_)
+#if defined(_SKIA_SUPPORT_)
   bool AttachSkiaImpl(RetainPtr<CFX_DIBitmap> pBitmap,
                       bool bRgbByteOrder,
                       RetainPtr<CFX_DIBitmap> pBackdropBitmap,
