@@ -1,4 +1,4 @@
-// Copyright 2016 PDFium Authors. All rights reserved.
+// Copyright 2016 The PDFium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -15,9 +15,11 @@
 #include <vector>
 
 #include "core/fxcrt/bytestring.h"
+#include "core/fxcrt/data_vector.h"
 #include "core/fxcrt/fx_coordinates.h"
 #include "core/fxcrt/fx_memory_wrappers.h"
 #include "core/fxcrt/fx_stream.h"
+#include "core/fxcrt/fx_string_wrappers.h"
 #include "core/fxcrt/retain_ptr.h"
 #include "core/fxcrt/unowned_ptr.h"
 #include "core/fxge/cfx_graphstatedata.h"
@@ -34,25 +36,14 @@ struct CFX_FillRenderOptions;
 struct FXDIB_ResampleOptions;
 
 struct EncoderIface {
-  bool (*pA85EncodeFunc)(pdfium::span<const uint8_t> src_buf,
-                         std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-                         uint32_t* dest_size);
-  void (*pFaxEncodeFunc)(const uint8_t* src_buf,
-                         int width,
-                         int height,
-                         int pitch,
-                         std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-                         uint32_t* dest_size);
-  bool (*pFlateEncodeFunc)(pdfium::span<const uint8_t> src_span,
-                           std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-                           uint32_t* dest_size);
+  DataVector<uint8_t> (*pA85EncodeFunc)(pdfium::span<const uint8_t> src_span);
+  DataVector<uint8_t> (*pFaxEncodeFunc)(RetainPtr<CFX_DIBBase> src);
+  DataVector<uint8_t> (*pFlateEncodeFunc)(pdfium::span<const uint8_t> src_span);
   bool (*pJpegEncodeFunc)(const RetainPtr<CFX_DIBBase>& pSource,
                           uint8_t** dest_buf,
                           size_t* dest_size);
-  bool (*pRunLengthEncodeFunc)(
-      pdfium::span<const uint8_t> src_buf,
-      std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-      uint32_t* dest_size);
+  DataVector<uint8_t> (*pRunLengthEncodeFunc)(
+      pdfium::span<const uint8_t> src_span);
 };
 
 class CFX_PSRenderer {
@@ -121,6 +112,30 @@ class CFX_PSRenderer {
  private:
   struct Glyph;
 
+  struct FaxCompressResult {
+    FaxCompressResult();
+    FaxCompressResult(const FaxCompressResult&) = delete;
+    FaxCompressResult& operator=(const FaxCompressResult&) = delete;
+    FaxCompressResult(FaxCompressResult&&) noexcept;
+    FaxCompressResult& operator=(FaxCompressResult&&) noexcept;
+    ~FaxCompressResult();
+
+    DataVector<uint8_t> data;
+    bool compressed = false;
+  };
+
+  struct PSCompressResult {
+    PSCompressResult();
+    PSCompressResult(const PSCompressResult&) = delete;
+    PSCompressResult& operator=(const PSCompressResult&) = delete;
+    PSCompressResult(PSCompressResult&&) noexcept;
+    PSCompressResult& operator=(PSCompressResult&&) noexcept;
+    ~PSCompressResult();
+
+    DataVector<uint8_t> data;
+    ByteString filter;
+  };
+
   void StartRendering();
   void EndRendering();
   void OutputPath(const CFX_Path& path, const CFX_Matrix* pObject2Device);
@@ -135,25 +150,18 @@ class CFX_PSRenderer {
                            const TextCharPos* char_pos,
                            CFX_Font* font,
                            float font_size,
-                           std::ostringstream& buf);
+                           fxcrt::ostringstream& buf);
   bool DrawTextAsType42Font(int char_count,
                             const TextCharPos* char_pos,
                             CFX_Font* font,
                             float font_size,
-                            std::ostringstream& buf);
-  bool FaxCompressData(std::unique_ptr<uint8_t, FxFreeDeleter> src_buf,
-                       int width,
-                       int height,
-                       std::unique_ptr<uint8_t, FxFreeDeleter>* dest_buf,
-                       uint32_t* dest_size) const;
-  void PSCompressData(uint8_t* src_buf,
-                      uint32_t src_size,
-                      uint8_t** output_buf,
-                      uint32_t* output_size,
-                      const char** filter) const;
+                            fxcrt::ostringstream& buf);
+  FaxCompressResult FaxCompressData(RetainPtr<CFX_DIBBase> src) const;
+  absl::optional<PSCompressResult> PSCompressData(
+      pdfium::span<const uint8_t> src_span) const;
   void WritePreambleString(ByteStringView str);
   void WritePSBinary(pdfium::span<const uint8_t> data);
-  void WriteStream(std::ostringstream& stream);
+  void WriteStream(fxcrt::ostringstream& stream);
   void WriteString(ByteStringView str);
 
   bool m_bInited = false;
@@ -167,8 +175,8 @@ class CFX_PSRenderer {
   UnownedPtr<const EncoderIface> const m_pEncoderIface;
   RetainPtr<IFX_RetainableWriteStream> m_pStream;
   std::vector<std::unique_ptr<Glyph>> m_PSFontList;
-  std::ostringstream m_PreambleOutput;
-  std::ostringstream m_Output;
+  fxcrt::ostringstream m_PreambleOutput;
+  fxcrt::ostringstream m_Output;
   std::vector<FX_RECT> m_ClipBoxStack;
 };
 
