@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#define FC_NUM_CASE_FOLD	288
+#define FC_NUM_CASE_FOLD	295
 #define FC_NUM_CASE_FOLD_CHARS	471
 #define FC_MAX_CASE_FOLD_CHARS	6
 #define FC_MAX_CASE_FOLD_EXPAND	4
@@ -146,6 +146,8 @@ static const FcCaseFold    fcCaseFold[FC_NUM_CASE_FOLD] = {
     { 0x00001c86, FC_CASE_FOLD_RANGE,    0x0001,  -6204 },
     { 0x00001c87, FC_CASE_FOLD_RANGE,    0x0001,  -6180 },
     { 0x00001c88, FC_CASE_FOLD_RANGE,    0x0001, -30269 },
+    { 0x00001c90, FC_CASE_FOLD_RANGE,    0x002b,  -3008 },
+    { 0x00001cbd, FC_CASE_FOLD_RANGE,    0x0003,  -3008 },
     { 0x00001e00, FC_CASE_FOLD_EVEN_ODD, 0x0095,      1 },
     { 0x00001e96, FC_CASE_FOLD_FULL,     0x0003,     27 },
     { 0x00001e97, FC_CASE_FOLD_FULL,     0x0003,     30 },
@@ -298,7 +300,11 @@ static const FcCaseFold    fcCaseFold[FC_NUM_CASE_FOLD] = {
     { 0x0000a7b1, FC_CASE_FOLD_RANGE,    0x0001,  23254 },
     { 0x0000a7b2, FC_CASE_FOLD_RANGE,    0x0001,  23275 },
     { 0x0000a7b3, FC_CASE_FOLD_RANGE,    0x0001,    928 },
-    { 0x0000a7b4, FC_CASE_FOLD_EVEN_ODD, 0x0003,      1 },
+    { 0x0000a7b4, FC_CASE_FOLD_EVEN_ODD, 0x000b,      1 },
+    { 0x0000a7c2, FC_CASE_FOLD_EVEN_ODD, 0x0001,      1 },
+    { 0x0000a7c4, FC_CASE_FOLD_RANGE,    0x0001,    -48 },
+    { 0x0000a7c5, FC_CASE_FOLD_RANGE,    0x0001,  23229 },
+    { 0x0000a7c6, FC_CASE_FOLD_RANGE,    0x0001,  30152 },
     { 0x0000ab70, FC_CASE_FOLD_RANGE,    0x0050,  26672 },
     { 0x0000fb00, FC_CASE_FOLD_FULL,     0x0002,    435 },
     { 0x0000fb01, FC_CASE_FOLD_FULL,     0x0002,    437 },
@@ -317,6 +323,7 @@ static const FcCaseFold    fcCaseFold[FC_NUM_CASE_FOLD] = {
     { 0x000104b0, FC_CASE_FOLD_RANGE,    0x0024,     40 },
     { 0x00010c80, FC_CASE_FOLD_RANGE,    0x0033,     64 },
     { 0x000118a0, FC_CASE_FOLD_RANGE,    0x0020,     32 },
+    { 0x00016e40, FC_CASE_FOLD_RANGE,    0x0020,     32 },
     { 0x0001e900, FC_CASE_FOLD_RANGE,    0x0022,     34 },
 };
 
