@@ -63,7 +63,6 @@ MWAWPictMac::ReadResult MWAWPictMac::checkOrGet
   int version, subvers;
   // we can not read the data, ...
   long actualPos = input->tell();
-  input->seek(actualPos,librevenge::RVNG_SEEK_SET);
   if (size < 0xd)
     return MWAW_R_BAD;
 
@@ -74,7 +73,8 @@ MWAWPictMac::ReadResult MWAWPictMac::checkOrGet
   bool empty = false;
   switch (lastFlag) {
   case 0x1101: {
-    if (readSize != size && readSize+1 != size)
+    // some MacDraw Pro pict stores a bigger size 512(file header?)+10?
+    if (readSize != size && readSize+1 != size && (actualPos!=512 || readSize != size+512+10))
       return MWAW_R_BAD;
     version = subvers = 1;
     empty = (size == 0xd);
@@ -1206,7 +1206,7 @@ bool PictParser::convertToPict2(librevenge::RVNGBinaryData const &orig, libreven
 
     OpCode const &opCode = it->second;
     sz = 0;
-    if (!opCode.computeSize(*input, sz)) {
+    if (!opCode.computeSize(*input, sz) || !input->checkPosition(input->tell()+sz)) {
       MWAW_DEBUG_MSG(("Pict1:convertToPict2 can not compute size for opCode 0x%x\n", static_cast<unsigned int>(code)));
       return false;
     }
