@@ -939,7 +939,6 @@ bool Quattro9Spreadsheet::readCellStyles(std::shared_ptr<WPSStream> const &strea
 	}
 	ascFile.addPos(pos);
 	ascFile.addNote(f.str().c_str());
-	int val;
 	long actSize=long(m_state->m_stylesList.size());
 	m_state->m_stylesList.resize(size_t(actSize+N));
 	for (long i=actSize; i<actSize+N; ++i)
@@ -1025,7 +1024,7 @@ bool Quattro9Spreadsheet::readCellStyles(std::shared_ptr<WPSStream> const &strea
 		}
 		flag &= 0xfb08;
 		if (flag) f << "fl=" << std::hex << flag << std::dec << ",";
-		val=int(libwps::readU16(input));
+		int val=int(libwps::readU16(input));
 		if (val&1) f << "not[protected],";
 		val&=0xfffe;
 		if (val) f << "f1=" << std::hex << val << std::dec << ",";
@@ -1350,7 +1349,7 @@ bool Quattro9Spreadsheet::readEndSheet(std::shared_ptr<WPSStream> const &stream)
 	}
 	m_state->m_actualSpreadsheet.reset();
 	long filePos[2]; // f0=pointer to a previous zone 601|602
-	m_mainParser.readFilePositions(stream, filePos);
+	Quattro9Parser::readFilePositions(stream, filePos);
 	return true;
 }
 
@@ -1587,7 +1586,7 @@ bool Quattro9Spreadsheet::readEndColumn(std::shared_ptr<WPSStream> const &stream
 	}
 	m_state->m_actualColumn=-1;
 	long filePos[2]; // f0=pointer to a previous zone a01|a02
-	m_mainParser.readFilePositions(stream, filePos);
+	Quattro9Parser::readFilePositions(stream, filePos);
 	return true;
 }
 
@@ -1878,7 +1877,7 @@ bool Quattro9Spreadsheet::readCellResult(std::shared_ptr<WPSStream> const &strea
 // formula
 ////////////////////////////////////////////////////////////
 bool Quattro9Spreadsheet::readCell
-(std::shared_ptr<WPSStream> const &stream, Vec2i actPos, WKSContentListener::FormulaInstruction &instr, int sheetId, librevenge::RVNGString const &fName) const
+(std::shared_ptr<WPSStream> const &stream, Vec2i actPos, WKSContentListener::FormulaInstruction &instr, int sheetId, librevenge::RVNGString const &fName)
 {
 	RVNGInputStreamPtr input = stream->m_input;
 	instr=WKSContentListener::FormulaInstruction();
