@@ -102,7 +102,7 @@ struct SfxMultiRecord {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       return false;
     }
-    if (m_zoneType==char(0xff)) {
+    if (m_zoneType==static_cast<unsigned char>(0xff)) {
       STOFF_DEBUG_MSG(("StarFileManagerInternal::SfxMultiRecord: oops end header\n"));
       m_extra="###emptyZone,";
       return true; /* empty zone*/
@@ -247,7 +247,7 @@ protected:
   //! the main zone
   StarZone &m_zone;
   //! the zone type
-  char m_zoneType;
+  unsigned char m_zoneType;
   //! true if a SfxRecord has been opened
   bool m_zoneOpened;
   //! the record type
@@ -684,7 +684,6 @@ try
       dataType=graphic.m_object.m_typeList.empty() ? "image/pict" : graphic.m_object.m_typeList[0];
       if (!graphic.m_object.m_dataList.empty())
         data=graphic.m_object.m_dataList[0];
-      extension="pict";
       return true;
     }
     dataType="image/pict";
