@@ -42,7 +42,6 @@
 #include "MWAWTextListener.hxx"
 #include "MWAWHeader.hxx"
 #include "MWAWFont.hxx"
-#include "MWAWFontConverter.hxx"
 #include "MWAWPosition.hxx"
 #include "MWAWPictMac.hxx"
 #include "MWAWPrinter.hxx"
@@ -433,10 +432,10 @@ bool WriteNowParser::readDocEntries()
       ascii().addNote("Entries(Free)");
     }
   }
-  char const *(entryName[]) = { "TextZone", "TextZone", "TextZone", "UnknZone0",
-                                "GraphZone", "ColMap", "StylZone", "FontZone",
-                                "UnknZone1", "UnknZone2"
-                              };
+  char const *entryName[] = { "TextZone", "TextZone", "TextZone", "UnknZone0",
+                              "GraphZone", "ColMap", "StylZone", "FontZone",
+                              "UnknZone1", "UnknZone2"
+                            };
   for (int i = 0; i < 10; i++) {
     WriteNowEntry zone = readEntry();
     zone.setType(entryName[i]);
